@@ -10,17 +10,15 @@ import json
 from pathlib import Path
 from typing import List
 
-from tqdm import tqdm
-
 from acamodels import ArchiveFile
+from tqdm import tqdm
 
 # -----------------------------------------------------------------------------
 # Function Definitions
 # -----------------------------------------------------------------------------
 
 
-def fix_extensions(files: List[ArchiveFile]) -> bool:
-    fixed: bool
+def fix_extensions(files: List[ArchiveFile]) -> List[ArchiveFile]:
     map_path = Path(__file__).parents[1] / "_data" / "ext_map.json"
     ext_map = json.load(map_path.open(encoding="utf-8"))
     to_fix = [
@@ -29,7 +27,11 @@ def fix_extensions(files: List[ArchiveFile]) -> bool:
         if "Extension mismatch" in (file.warning or "")
         and file.puid in ext_map
     ]
-    for file in tqdm(to_fix, desc="Fixing file extensions"):
+    for file in tqdm(
+        to_fix, desc="Fixing file extensions", disable=not to_fix
+    ):
         new_name = file.path.with_name(f"{file.name()}.{ext_map[file.puid]}")
         file.path.rename(new_name)
-    return bool(to_fix)
+        file.path = new_name
+
+    return to_fix
